@@ -86,6 +86,10 @@ class Segment(proto.Message):
 
         cutoff_high (float):
 
+        platform (str):
+
+        highlevel_type (str):
+
     """
 
     segment = proto.Field(proto.STRING, number=1)
@@ -104,6 +108,10 @@ class Segment(proto.Message):
 
     cutoff_high = proto.Field(proto.DOUBLE, number=8)
 
+    platform = proto.Field(proto.STRING, number=9)
+
+    highlevel_type = proto.Field(proto.STRING, number=10)
+
 
 class ListPortsResponse(proto.Message):
     r"""List Ports
@@ -351,6 +359,8 @@ class Commodity(proto.Message):
 
         commodity_group (str):
 
+        platform (str):
+
     """
 
     commodity = proto.Field(proto.STRING, number=1)
@@ -361,6 +371,8 @@ class Commodity(proto.Message):
 
     commodity_group = proto.Field(proto.STRING, number=3)
 
+    platform = proto.Field(proto.STRING, number=5)
+
 
 class ListCommoditiesResponse(proto.Message):
     r"""
