@@ -72,7 +72,7 @@ class PortCallServiceClientMeta(type):
 
 
 class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
-    """PortCallService provides service to get PortCall data"""
+    """PortCallService provides an API service to get PortCall data"""
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
@@ -373,7 +373,7 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetPortCallTimeseriesResponse:
         r"""GetPortCallTimeseries retrieves aggregated counts for
-        port calls for a set of request params
+        port calls for a set of request params.
 
         Args:
             request (oceanbolt.com.portcalls_v3.types.GetPortCallsRequest):
