@@ -2,10 +2,10 @@ from oceanbolt.sdk.client import APIClient
 from oceanbolt.sdk.data import Ports, Countries, Commodities, Segments, Regions, Zones, Search
 from oceanbolt.sdk.data import TradeFlows, TradeFlowTimeseries
 from oceanbolt.sdk.data import PortCalls, PortCallTimeseries, PortParticulars
-from oceanbolt.sdk.data import TonnageZoneTimeseries, FleetSpeedTimeseries, ChineseWatersTimeseries, FleetStatusTimeseries, FleetGrowthTimeseries, ZoneChangesTimeseries, CustomPolygonTimeseries
+from oceanbolt.sdk.data import TonnageZoneTimeseries, FleetSpeedTimeseries, ChineseWatersTimeseries, FleetStatusTimeseries, FleetGrowthTimeseries, ZoneChangesTimeseries
 from oceanbolt.sdk.data import CongestionVessels, CongestionTimeseries
 from oceanbolt.sdk.data import DryDockTimeseries, DryDockCurrentVessels, DryDockHistoricalStays
-from oceanbolt.sdk.data import Vessels, StoppageEvents
+from oceanbolt.sdk.data import Vessels
 
 __client__ = APIClient()
 
@@ -148,6 +148,7 @@ def test_trade_flow_timeseries():
     df = TradeFlowTimeseries(__client__).get(frequency="monthly", load_country_code=["cn"], start_date="2021-01-01")
     assert len(df) > 0
 
+
 # Vessels Service
 def test_vessels():
     df = Vessels(__client__).get(segment=["supramax"])
@@ -156,4 +157,4 @@ def test_vessels():
 
 def test_stoppage_events():
     df = Vessels(__client__).get(imo=[9583706])
-    assert len(df) > 0
\ No newline at end of file
+    assert len(df) > 0
