@@ -433,6 +433,8 @@ def test_create_fleet(transport: str = 'grpc', request_type=service.CreateFleetR
 
             fleet_name='fleet_name_value',
 
+            platform='platform_value',
+
             owner_user_id='owner_user_id_value',
 
             organization='organization_value',
@@ -455,6 +457,8 @@ def test_create_fleet(transport: str = 'grpc', request_type=service.CreateFleetR
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -483,6 +487,7 @@ async def test_create_fleet_async(transport: str = 'grpc_asyncio', request_type=
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(service.Fleet(
             fleet_id='fleet_id_value',
             fleet_name='fleet_name_value',
+            platform='platform_value',
             owner_user_id='owner_user_id_value',
             organization='organization_value',
         ))
@@ -502,6 +507,8 @@ async def test_create_fleet_async(transport: str = 'grpc_asyncio', request_type=
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -603,6 +610,8 @@ def test_describe_fleet(transport: str = 'grpc', request_type=service.GetFleetRe
 
             fleet_name='fleet_name_value',
 
+            platform='platform_value',
+
             owner_user_id='owner_user_id_value',
 
             organization='organization_value',
@@ -625,6 +634,8 @@ def test_describe_fleet(transport: str = 'grpc', request_type=service.GetFleetRe
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -653,6 +664,7 @@ async def test_describe_fleet_async(transport: str = 'grpc_asyncio', request_typ
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(service.Fleet(
             fleet_id='fleet_id_value',
             fleet_name='fleet_name_value',
+            platform='platform_value',
             owner_user_id='owner_user_id_value',
             organization='organization_value',
         ))
@@ -672,6 +684,8 @@ async def test_describe_fleet_async(transport: str = 'grpc_asyncio', request_typ
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -702,6 +716,8 @@ def test_rename_fleet(transport: str = 'grpc', request_type=service.RenameFleetR
 
             fleet_name='fleet_name_value',
 
+            platform='platform_value',
+
             owner_user_id='owner_user_id_value',
 
             organization='organization_value',
@@ -724,6 +740,8 @@ def test_rename_fleet(transport: str = 'grpc', request_type=service.RenameFleetR
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -752,6 +770,7 @@ async def test_rename_fleet_async(transport: str = 'grpc_asyncio', request_type=
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(service.Fleet(
             fleet_id='fleet_id_value',
             fleet_name='fleet_name_value',
+            platform='platform_value',
             owner_user_id='owner_user_id_value',
             organization='organization_value',
         ))
@@ -771,6 +790,8 @@ async def test_rename_fleet_async(transport: str = 'grpc_asyncio', request_type=
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -801,6 +822,8 @@ def test_share_fleet(transport: str = 'grpc', request_type=service.ShareFleetReq
 
             fleet_name='fleet_name_value',
 
+            platform='platform_value',
+
             owner_user_id='owner_user_id_value',
 
             organization='organization_value',
@@ -823,6 +846,8 @@ def test_share_fleet(transport: str = 'grpc', request_type=service.ShareFleetReq
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -851,6 +876,7 @@ async def test_share_fleet_async(transport: str = 'grpc_asyncio', request_type=s
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(service.Fleet(
             fleet_id='fleet_id_value',
             fleet_name='fleet_name_value',
+            platform='platform_value',
             owner_user_id='owner_user_id_value',
             organization='organization_value',
         ))
@@ -870,6 +896,8 @@ async def test_share_fleet_async(transport: str = 'grpc_asyncio', request_type=s
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -900,6 +928,8 @@ def test_unshare_fleet(transport: str = 'grpc', request_type=service.ShareFleetR
 
             fleet_name='fleet_name_value',
 
+            platform='platform_value',
+
             owner_user_id='owner_user_id_value',
 
             organization='organization_value',
@@ -922,6 +952,8 @@ def test_unshare_fleet(transport: str = 'grpc', request_type=service.ShareFleetR
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
@@ -950,6 +982,7 @@ async def test_unshare_fleet_async(transport: str = 'grpc_asyncio', request_type
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(service.Fleet(
             fleet_id='fleet_id_value',
             fleet_name='fleet_name_value',
+            platform='platform_value',
             owner_user_id='owner_user_id_value',
             organization='organization_value',
         ))
@@ -969,6 +1002,8 @@ async def test_unshare_fleet_async(transport: str = 'grpc_asyncio', request_type
 
     assert response.fleet_name == 'fleet_name_value'
 
+    assert response.platform == 'platform_value'
+
     assert response.owner_user_id == 'owner_user_id_value'
 
     assert response.organization == 'organization_value'
